@@ -80,7 +80,7 @@ setMethodS3("dimnames<-", "AromaTabularBinaryFile", function(x, value) {
   this <- x;
 
   throw("Dimension names of an ", class(this)[1], " are read only.");
-}, createGeneric=FALSE, appendVarArgs=FALSE, protected=TRUE)
+}, appendVarArgs=FALSE, protected=TRUE)
 
 
 setMethodS3("readHeader", "AromaTabularBinaryFile", function(this, con=NULL, ..., force=FALSE) {
@@ -1297,10 +1297,6 @@ setMethodS3("colMeans", "AromaTabularBinaryFile", function(x, ...) {
   colStats(x, FUN=mean, ...);
 })
 
-setMethodS3("colMedians", "AromaTabularBinaryFile", function(x, ...) {
-  colStats(x, FUN=median, ...);
-})
-
 setMethodS3("importFrom", "AromaTabularBinaryFile", function(this, srcFile, ...) {
   methodNames <- sprintf("importFrom%s", class(srcFile));
 
