@@ -19,7 +19,8 @@ setMethodS3("exportTotalCnRatioSet", "AromaUnitTotalCnBinarySet", function(this,
   if (inherits(ref, "AromaUnitTotalCnBinaryFile")) {
     refList <- rep(list(ref), nbrOfFiles);
     refSet <- AromaUnitTotalCnBinarySet(refList);
-    rm(refList);
+    # Not needed anymore
+    refList <- NULL;
   }
 
   if (inherits(ref, "AromaUnitTotalCnBinarySet")) {
@@ -55,7 +56,7 @@ setMethodS3("exportTotalCnRatioSet", "AromaUnitTotalCnBinarySet", function(this,
     pushState(verbose);
     on.exit(popState(verbose));
   }
- 
+
 
   verbose && enter(verbose, "Calculating CN ratios");
   dataSet <- getFullName(this);
@@ -98,7 +99,7 @@ setMethodS3("exportTotalCnRatioSet", "AromaUnitTotalCnBinarySet", function(this,
     # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     if (!is.null(refSet)) {
       ceR <- getFile(refSet, kk);
-      refName <- getFullName(ceR); 
+      refName <- getFullName(ceR);
       refName <- gsub(",(total|log2ratio)", "", refName);
       refTag <- sprintf("ref=%s", refName);
     } else {
@@ -128,7 +129,7 @@ setMethodS3("exportTotalCnRatioSet", "AromaUnitTotalCnBinarySet", function(this,
     asb <- AromaUnitSignalBinaryFile$allocate(pathnameT, nbrOfRows=nbrOfUnits(ce), platform=platform, chipType=chipType);
     verbose && print(verbose, asb);
     verbose && exit(verbose);
-  
+
 
     # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     # Calculating relative CNs
@@ -177,7 +178,8 @@ setMethodS3("exportTotalCnRatioSet", "AromaUnitTotalCnBinarySet", function(this,
     verbose && cat(verbose, "Copy-number ratios:");
     C <- theta / thetaR;
     verbose && str(verbose, C);
-    rm(theta);
+    # Not needed anymore
+    theta <- NULL;
 
     # Log ratios?
     if (!is.null(logBase)) {
@@ -194,7 +196,8 @@ setMethodS3("exportTotalCnRatioSet", "AromaUnitTotalCnBinarySet", function(this,
     verbose && enter(verbose, "Updating temporary output file");
     # Store data
     asb[,1] <- C;
-    rm(C);
+    # Not needed anymore
+    C <- NULL;
 
 
     # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -205,10 +208,10 @@ setMethodS3("exportTotalCnRatioSet", "AromaUnitTotalCnBinarySet", function(this,
         dataSet=dataSet,
         fullName=getFullName(ceR),
         filename=getFilename(ceR),
-        checksum=getChecksum(ceR) 
+        checksum=getChecksum(ceR)
       );
     } else {
-      refFile <- list(thetaR=digest2(thetaR));
+      refFile <- list(thetaR=getChecksum(thetaR));
     }
 
     footer <- readFooter(asb);
@@ -217,12 +220,13 @@ setMethodS3("exportTotalCnRatioSet", "AromaUnitTotalCnBinarySet", function(this,
         dataSet=dataSet,
         fullName=getFullName(ce),
         filename=getFilename(ce),
-        checksum=getChecksum(ce) 
+        checksum=getChecksum(ce)
       ),
       refFile = refFile
     );
     writeFooter(asb, footer);
-    rm(footer, refFile);
+    # Not needed anymore
+    footer <- refFile <- NULL;
     verbose && exit(verbose);
 
 
@@ -255,7 +259,7 @@ setMethodS3("exportTotalCnRatioSet", "AromaUnitTotalCnBinarySet", function(this,
 # 2009-09-24
 # o Added more verbose output.
 # 2009-06-13
-# o BUG FIX: exportTotalCnRatioSet() would return a 
+# o BUG FIX: exportTotalCnRatioSet() would return a
 #   AromaUnitFracBCnBinarySet.
 # 2009-05-17
 # o BUG FIX: exportTotalCnRatioSet() would return any signal file.
